+++
title = "Type Front-matter"
tags = ["front-matter", "type"]
type = "type-test"
draft = false
+++

The `type` front-matter is used to override the default **section** type
(automatically derived from the directory of the content page).

Here the type is overridden to be `type-test`.

[Reference](https://gohugo.io/content-management/front-matter/#predefined)
